'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = freeze;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _deepFreeze = require('deep-freeze');

var _deepFreeze2 = _interopRequireDefault(_deepFreeze);

/**
 * Middleware that prevents state from being mutated anywhere in the app.
 */

function freeze(store) {
  return function (next) {
    return function (action) {
      freezeStoreState(store);
      try {
        return next(action);
      } finally {
        freezeStoreState(store);
      }
    };
  };
}

function freezeStoreState(store) {
  var state = store.getState();
  if (isFreezable(state)) (0, _deepFreeze2['default'])(state);
}

function isFreezable(value) {
  return value !== null && typeof value === 'object';
}
module.exports = exports['default'];